from enum import Enum
from typing import Optional

from pydantic import BaseModel, ConfigDict, Field


class CustomizedScorerName(str, Enum):
    chunk_attribution_utilization_plus = "_customized_chunk_attribution_utilization_gpt"
    completeness_plus = "_customized_completeness_gpt"
    context_adherence_plus = "_customized_groundedness"
    correctness = "_customized_factuality"


class CustomizedScorer(BaseModel):
    scorer_name: CustomizedScorerName = Field(..., description="Name of the customized scorer.")
    model_alias: Optional[str] = Field(None, description="Model alias to use for scoring.")
    num_judges: Optional[int] = Field(None, ge=1, le=10, description="Number of judges for the scorer.")

    model_config = ConfigDict(
        # Avoid Pydantic's protected namespace warning since we want to use
        # `model_alias` as a field name.
        protected_namespaces=(),
    )
